#ifndef __XML_PARSER_H_
#define __XML_PARSER_H_

#include <libxml/parser.h>

#ifdef __cplusplus
extern "C" {
#endif

/** Debugging output
@param point The error occured here
@return Error code
*/
int xml_err (char *point);
/** Name of an XML node
@param node The node to work with
@return The name
*/
char *xml_name (xmlNodePtr node);
/** Value of an XML node
@param node The node to work with
@return The value
*/
char *xml_val (xmlNodePtr node);
/** Value of a certain property
@param node The XML node to work with
@param property Name of the property wanted
@return The value 
*/
char *xml_prop (xmlNodePtr node, char *property);
/** Dump an XML node to a file
@param file The file to dump to (stdout for screen)
@param node The node to work with
*/
void xml_print (FILE *file, xmlNodePtr node);
/** Search a XML subtree for a certain node
@param root Root of the XML subtree
@param sstr Name of the node wanted
@return Pointer to the requested node
*/
xmlNodePtr xml_searchptr (xmlNodePtr root, char *sstr);
/** Search a XML subtree for a certain node
@param root Root of the XML subtree
@param sstr Name of the node wanted
@return Value of the requested node (empty if the node is not found)
*/
char *xml_searchval (xmlNodePtr root, char *sstr);
/** Dump an XML tree to screen for debugging purposes
@param file The file to dump to (stdout for screen)
@param root The root of the XML tree 
*/
void xml_dump_tree (FILE *file, xmlNodePtr root);
/** Returns the last element on node's tree height
@param node The node to work with
@return Pointer to the element
*/
xmlNodePtr xml_last (xmlNodePtr node);

#ifdef __cplusplus
}
#endif
#endif
